"""
Here you can create samples of your widgets by providing default parameters,
inserting them in a container widget, mixing them with other widgets, etc...
These samples will appear in the WidgetBrowser

See http://toscawidgets.org/documentation/WidgetBrowser for more information
"""

from widgets import *


class DemoChosenSingleSelectField(ChosenSingleSelectField):
    options = [('Group 1', ['Item 1', 'Item 2']),
        ('Group 2', ['Item 3', 'Item 4', 'Item 5', 'Item 6'])]
    value = 'Item 2'
    attrs = dict(style='width: 200px')


class DemoChosenMultipleSelectField(ChosenMultipleSelectField):
    options = [('Group 1', ['Item 1', 'Item 2']),
        ('Group 2', ['Item 3', 'Item 4', 'Item 5', 'Item 6'])]
    #value = ['Item 2', 'Item 5']
    placeholder = 'Select an item, you won\'t regret it'
    attrs = dict(style='width: 400px')



'''
Chosen is a JavaScript plugin that makes long,
unwieldy select boxes much more user-friendly.

For more information about Chosen, see:
http://harvesthq.github.com/chosen/
'''

from widgets import *


import tw2.core as twc
import tw2.forms as twf
import tw2.jquery as twj

__all__ = [
    'chosen_img',
    'chosen_js',
    'chosen_css',
    'ChosenSingleSelectField',
    'ChosenMultipleSelectField']


chosen_img = twc.Link(
    modname=__name__,
    filename='static/chosen-sprite.png')
chosen_js = twc.JSLink(
    modname=__name__,
    filename='static/chosen.jquery.js',
    resources=[twj.jquery_js],
    location='headbottom')
chosen_css = twc.CSSLink(
    modname=__name__,
    filename='static/chosen.css')


class ChosenMixin(twc.Widget):
    '''Mixin for Chosen SelectFields'''
    resources = [chosen_js, chosen_css]

    selector = twc.Variable("Escaped id.  jQuery selector.")
    opts = twc.Variable(
        'Arguments for the javascript init function',
        default=dict())

    placeholder = twc.Param(
        'Placeholder text, prompting user for selection',
        default='')
    no_results_text = twc.Param(
        'Text shown when the search term returned no results',
        default='')

    def prepare(self):
        super(ChosenMixin, self).prepare()
        # put code here to run just before the widget is displayed
        if 'id' in self.attrs:
            self.selector = "#" + self.attrs['id'].replace(':', '\\:')

        if self.placeholder:
            self.attrs['data-placeholder'] = self.placeholder
        if self.no_results_text:
            self.opts['no_results_text'] = self.no_results_text

        self.add_call(twj.jQuery(self.selector).chosen(self.opts))


class ChosenSingleSelectField(ChosenMixin, twf.SingleSelectField):
    '''SingleSelectField, enhanced with Chosen javascript'''
    def prepare(self):
        # If field is not required, this adds a button for deselection
        if not self.required:
            self.opts['allow_single_deselect'] = True
        super(ChosenSingleSelectField, self).prepare()


class ChosenMultipleSelectField(ChosenMixin, twf.MultipleSelectField):
    '''MultipleSelectField, enhanced with Chosen javascript'''
    pass



from setuptools import setup, find_packages

# Odd hack to get tests running smoothly on py2.7
try:
    import multiprocessing
    import logging
except:
    pass

setup(
    name='tw2.jqplugins.chosen',
    version='0.1',
    description='ToscaWidgets 2 SelectFields enhanced with the Chosen javascript library.',
    long_description=open('README.md').read(),
    author='Moritz Schlarb',
    author_email='mail@moritz-schlarb.de',
    url='https://github.com/toscawidgets/tw2.jqplugins.chosen',
    license='MIT',
    install_requires=[
        "tw2.core",
        "tw2.forms",
        "tw2.jquery",
        ],
    packages=find_packages(exclude=['ez_setup', 'tests']),
    namespace_packages = ['tw2'],
    zip_safe=False,
    include_package_data=True,
    tests_require = [
        'nose',
        'BeautifulSoup',
        'FormEncode',
        'WebTest',
        'strainer',

        'mako',
        'genshi',
    ],
    test_suite = 'nose.collector',
    entry_points="""
        [tw2.widgets]
        # Register your widgets so they can be listed in the WidgetBrowser
        widgets = tw2.jqplugins.chosen
    """,
    keywords = [
        'toscawidgets.widgets',
    ],
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Environment :: Web Environment :: ToscaWidgets',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Widget Sets',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
)
